RcppFastAD-package: 'Rcpp' Bindings to 'FastAD' Auto-Differentiation

RcppFastAD-packageR Documentation

'Rcpp' Bindings to 'FastAD' Auto-Differentiation

Description

The header-only 'C++' template library 'FastAD' for automatic differentiation <https://github.com/JamesYang007/FastAD> is provided by this package, along with a few illustrative examples that can all be called from R.

Package Content

Index: This package was not yet installed at build time.

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), James Yang [aut] (ORCID: <https://orcid.org/0000-0002-0015-7812>)


RcppFastAD documentation built on Oct. 1, 2026, 5:08 p.m.